@@ -134,7 +134,7 @@ static void about_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
 		"Copyright \xc2\xa9 2003 Sun Microsystems";
 
 	gtk_show_about_dialog(NULL,
@@ -153,7 +153,14 @@ static void help_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 	GError* error = NULL;
 	GdkScreen* screen = gtk_widget_get_screen(GTK_WIDGET(sapplet->applet));
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	gtk_show_uri_on_window(NULL,
+	                       "help:mate-accessx-status",
+	                       gtk_get_current_event_time(),
+	                       &error);
+#else
 	gtk_show_uri(screen, "help:mate-accessx-status", gtk_get_current_event_time(), &error);
+#endif
 
 	if (error)
 	{
