@@ -174,7 +174,7 @@ about_cb (GtkAction   *action,
 	};
 
     char copyright[] = \
-                "Copyright \xc2\xa9 2012-2017 MATE developers\n"
+                "Copyright \xc2\xa9 2012-2016 MATE developers\n"
                 "Copyright \xC2\xA9 1999 Dave Camp";
 
 	const gchar *documenters[] = {
@@ -342,10 +342,17 @@ help_cb (GtkAction  *action,
 {
 	GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	gtk_show_uri_on_window (NULL,
+	                        "help:mate-geyes",
+	                        gtk_get_current_event_time (),
+	                        &error);
+#else
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
-		"help:mate-geyes",
-		gtk_get_current_event_time (),
-		&error);
+	              "help:mate-geyes",
+	              gtk_get_current_event_time (),
+	              &error);
+#endif
 
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
